@@ -4,7 +4,7 @@ from __future__ import annotations as _annotations
 
 from collections.abc import Sequence
 from pathlib import Path
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, Literal
 
 if TYPE_CHECKING:
     from pydantic._internal._dataclasses import PydanticDataclass
@@ -31,6 +31,7 @@ class ForceDecode:
     pass
 
 
+EnvPrefixTarget = Literal['variable', 'alias', 'all']
 DotenvType = Path | str | Sequence[Path | str]
 PathType = Path | str | Sequence[Path | str]
 DEFAULT_PATH: PathType = Path('')
@@ -53,6 +54,14 @@ class _CliImplicitFlag:
     pass
 
 
+class _CliToggleFlag(_CliImplicitFlag):
+    pass
+
+
+class _CliDualFlag(_CliImplicitFlag):
+    pass
+
+
 class _CliExplicitFlag:
     pass
 
@@ -61,17 +70,29 @@ class _CliUnknownArgs:
     pass
 
 
+class SecretVersion:
+    def __init__(self, version: str) -> None:
+        self.version = version
+
+    def __repr__(self) -> str:
+        return f'{self.__class__.__name__}({self.version!r})'
+
+
 __all__ = [
     'DEFAULT_PATH',
     'ENV_FILE_SENTINEL',
+    'EnvPrefixTarget',
     'DotenvType',
     'EnvNoneType',
     'ForceDecode',
     'NoDecode',
     'PathType',
     'PydanticModel',
+    'SecretVersion',
     '_CliExplicitFlag',
     '_CliImplicitFlag',
+    '_CliToggleFlag',
+    '_CliDualFlag',
     '_CliPositionalArg',
     '_CliSubCommand',
     '_CliUnknownArgs',
